@@ -4,7 +4,7 @@
 #'
 #' @description Given the station ID number(s), this function retrieves data
 #' (time series in zoo format with accompanying metadata) from the WaterML2
-#' service on the NRFA database. Gauged Daily Flow is measured in mm/day.
+#' service on the NRFA database. Gauged Daily Flow is measured in \eqn{m^3}/s.
 #'
 #' @param id station ID number(s), each number should be in the range
 #' [3002,236051].
@@ -14,8 +14,6 @@
 #' @param cl (optional) This is a cluster object, created by the parallel
 #' package. This is set to NULL by default, which sends sequential calls to the
 #' server.
-#' @param verbose (FALSE by default). If set to TRUE prints GET request on the
-#' console.
 #'
 #' @return list composed of as many objects as in the list of station ID
 #' numbers. Each object can be accessed using their names or index
@@ -30,9 +28,9 @@
 #' }
 #'
 
-gdf <- function(id, metadata = FALSE, cl = NULL, verbose = FALSE) {
+gdf <- function(id, metadata = FALSE, cl = NULL) {
 
-  flow <- get_ts(id, type = "gdf", metadata, cl, verbose)
+  flow <- get_ts(id, type = "gdf", metadata, cl)
 
   return(flow)
 
