@@ -3,16 +3,12 @@ context("Test cmr function")
 test_that("Output of cmr function for single station", {
 
   x <- cmr(id = 18019, metadata = FALSE, cl = NULL)
-
-  expect_that(length(x) >= 660, equals(TRUE))
+  expect_true(length(x) >= 660)
 
   x <- cmr(id = 18019, metadata = TRUE, cl = NULL)
-
   expect_that(length(x) == 2, equals(TRUE))
   expect_that(x$meta$station.name == "Comer Burn at Comer", equals(TRUE))
 
-  closeAllConnections()
-
 })
 
 test_that("Output of cmr function for multiple stations", {
@@ -32,6 +28,4 @@ test_that("Output of cmr function for multiple stations", {
 
   expect_that(all(names(y) == c("data", "meta")), equals(TRUE))
 
-  closeAllConnections()
-
 })
